@@ -62,12 +62,6 @@ tables matching -T are excluded from what is otherwise a normal dump.
     type=click.Choice(["mysql", "postgres", "redshift", "oracle"]),
     help="Type of database",
 )
-@click.option(
-    "-f",
-    "--output-format",
-    type=click.Choice(["ascii_table", "json", "db"]),
-    help="DEPRECATED. Please use --catalog-format",
-)
 @click.option(
     "-c",
     "--scan-type",
@@ -75,13 +69,6 @@ tables matching -T are excluded from what is otherwise a normal dump.
     default="shallow",
     help="Choose deep(scan data) or shallow(scan column names only)",
 )
-@click.option(
-    "-o",
-    "--output",
-    default=None,
-    type=click.File(),
-    help="DEPRECATED. Please use --catalog-file",
-)
 @click.option(
     "--list-all",
     default=False,
@@ -100,9 +87,7 @@ def cli(
     password,
     database,
     connection_type,
-    output_format,
     scan_type,
-    output,
     list_all,
     schema,
     exclude_schema,
@@ -125,18 +110,6 @@ def cli(
         exclude_table=exclude_table,
     )
 
-    if output_format is not None or output is not None:
-        logging.warning(
-            "--output-format and --output is deprecated. "
-            "Please use --catalog-format and --catalog-file"
-        )
-
-    if output_format is not None:
-        ns.catalog["format"] = output_format
-
-    if output is not None:
-        ns.catalog["file"] = output
-
     RelDbExplorer.dispatch(ns)
 
 
@@ -163,8 +136,10 @@ class RelDbExplorer(Explorer):
         explorer = None
         if ns.connection_type == "mysql":
             explorer = MySQLExplorer(ns)
-        elif ns.connection_type == "postgres" or ns.connection_type == "redshift":
+        elif ns.connection_type == "postgres":
             explorer = PostgreSQLExplorer(ns)
+        elif ns.connection_type == "redshift":
+            explorer = RedshiftExplorer(ns)
         elif ns.connection_type == "oracle":
             explorer = OracleExplorer(ns)
         assert explorer is not None
@@ -272,6 +247,23 @@ class PostgreSQLExplorer(RelDbExplorer):
         )
 
 
+class RedshiftExplorer(PostgreSQLExplorer):
+    _sample_query_template = "SELECT {column_list} FROM {schema_name}.{table_name} ORDER BY random() LIMIT 10"
+
+    def __init__(self, ns):
+        super(RedshiftExplorer, self).__init__(ns)
+
+    @classmethod
+    def _get_sample_query(cls, schema_name, table_name, column_list):
+        return cls._sample_query_template.format(
+            column_list='"{0}"'.format(
+                '","'.join(col.get_name() for col in column_list)
+            ),
+            schema_name=schema_name.get_name(),
+            table_name=table_name.get_name(),
+        )
+
+
 class OracleExplorer(RelDbExplorer):
     _catalog_query = """
         SELECT
