@@ -16,12 +16,6 @@ from piicatcher.explorer.explorer import Explorer
 @click.command("sqlite")
 @click.pass_context
 @click.option("-s", "--path", required=True, help="File path to SQLite database")
-@click.option(
-    "-f",
-    "--output-format",
-    type=click.Choice(["ascii_table", "json", "db"]),
-    help="DEPRECATED. Please use --catalog-format",
-)
 @click.option(
     "-c",
     "--scan-type",
@@ -29,13 +23,6 @@ from piicatcher.explorer.explorer import Explorer
     type=click.Choice(["deep", "shallow"]),
     help="Choose deep(scan data) or shallow(scan column names only)",
 )
-@click.option(
-    "-o",
-    "--output",
-    default=None,
-    type=click.File(),
-    help="DEPRECATED. Please use --catalog-file",
-)
 @click.option(
     "--list-all",
     default=False,
@@ -48,16 +35,7 @@ from piicatcher.explorer.explorer import Explorer
 @click.option("-T", "--exclude-table", multiple=True, help=exclude_table_help_text)
 # pylint: disable=too-many-arguments
 def cli(
-    cxt,
-    path,
-    output_format,
-    scan_type,
-    output,
-    list_all,
-    schema,
-    exclude_schema,
-    table,
-    exclude_table,
+    cxt, path, scan_type, list_all, schema, exclude_schema, table, exclude_table,
 ):
     args = Namespace(
         path=path,
@@ -70,18 +48,6 @@ def cli(
         exclude_table=exclude_table,
     )
 
-    if output_format is not None or output is not None:
-        logging.warning(
-            "--output-format and --output is deprecated. "
-            "Please use --catalog-format and --catalog-file"
-        )
-
-    if output_format is not None:
-        args.catalog["format"] = output_format
-
-    if output is not None:
-        args.catalog["file"] = output
-
     SqliteExplorer.dispatch(args)
 
 
@@ -135,7 +101,7 @@ class SqliteExplorer(Explorer):
         return self._catalog_query
 
     def _get_context_manager(self):
-        return SqliteExplorer.CursorContextManager(self.get_connection())
+        return SqliteExplorer.CursorContextManager(self.connection)
 
     @classmethod
     def _get_select_query(cls, schema_name, table_name, column_list):
